(define-package "agda2-mode" "2.6.1"
  "interactive development for Agda, a dependently typed functional programming language")
